#!/bin/sh

# Terminal width: 132 columns.


#
# Show where a given command is or that no such command was found.
#
whichfile() {
	if [ -z "$1" ]; then printf "%s\n" "(NOT SET)"; return; fi
	file="$( which "$1" 2>/dev/null )"; found=$?
	if [ 0 -eq $found ]; then printf "%s\n" "${file}"; else printf "%s\n" "(NOT FOUND)"; fi
}


#
# Show whether a given directory exists and is actually a directory.
#
whichdir() {
	if [ -z "$1" ]; then printf "%s\n" "NOT SET."; return; fi
	if [ ! -e "$1" ]; then printf "%s\n" "NOT FOUND."; fi
	if [ -d "$1" ]
	then printf "%s\n" "Found."
	else printf "%s\n" "NOT A DIRECTORY."
	fi
}


unset SRC_DIR PUB_DIR DST_DIR TMP_DIR TPL_DIR SITEMAP XLAT XLAT_OPTS1 XLAT_OPTS2 XLAT_OPTS3 RSYNC RSYNC_OPTS ADDRESS PYTHON

while getopts 's:p:d:t:l:m:x:1:2:3:r:o:a:y:' c
do
	case $c in
	s)  SRC_DIR="${OPTARG}"      ;;
	p)  PUB_DIR="${OPTARG}"      ;;
	d)  DST_DIR="${OPTARG}"      ;;
	t)  TMP_DIR="${OPTARG}"      ;;
	l)  TPL_DIR="${OPTARG}"      ;;
	m)  SITEMAP="${OPTARG}"      ;;
	x)  XLAT="${OPTARG}"         ;;
	1)  XLAT_OPTS1="${OPTARG}"   ;;
	2)  XLAT_OPTS2="${OPTARG}"   ;;
	3)  XLAT_OPTS3="${OPTARG}"   ;;
	r)  RSYNC="${OPTARG}"        ;;
	o)  RSYNC_OPTS="${OPTARG}"   ;;
	a)  ADDRESS="${OPTARG}"      ;;
	y)  PYTHON="${OPTARG}"       ;;
	*)  :                        ;;
	esac
done


#
# Check for required commands.
#
printf "%s\n" "Checking for required commands:"

for cmdname in which "[" basename cat comm dirname find fold grep m4 mktemp sed sort tar tr
do
	printf "%s" "${cmdname}: ";	whichfile "${cmdname}"
done

printf "%s\n" "Check that commands found above are correct.  Install any commands not found."


#
# Check for configured commands.
#
printf "\n%s\n" "Checking for configured commands:"

printf "%s" "XLAT '${XLAT}': "; whichfile "${XLAT}"
printf "%s" "PYTHON '${PYTHON}': "; whichfile "${PYTHON}"
printf "%s" "RSYNC '${RSYNC}': "; whichfile "${RSYNC}"

printf "%s\n" "Check that commands found above are correct.  Install any commands not found,"
printf "%s\n" "or edit 'config.mk' if any commands are misconfigured."


#
# Check for directories.
#
printf "\n%s\n" "Checking for configured directories:"

printf "%s" "SRC_DIR '${SRC_DIR}': "; whichdir "${SRC_DIR}"
printf "%s" "PUB_DIR '${PUB_DIR}': "; whichdir "${PUB_DIR}"
printf "%s" "DST_DIR '${DST_DIR}': "; whichdir "${DST_DIR}"
printf "%s" "TMP_DIR '${TMP_DIR}': "; whichdir "${TMP_DIR}"
printf "%s" "TPL_DIR '${TPL_DIR}': "; whichdir "${TPL_DIR}"

printf "%s\n" "Check that the above directories were found and are correct."
printf "%s\n" "Edit 'config.mk' and run \"make new\" if wrong or not found."


# End.

