#!/bin/sh

# Recompile bin/strptime from bin/strptime.c so it runs on this system.

#
# Verify that the source file is still present.
#
if [ ! -s "bin/strptime.c" ]
then
	printf "%s\n" "Source file 'bin/strptime.c' not found." >&2
	exit 1
fi

#
# Find the compiler.
#
CC="c99"
if                        ! which c99 >/dev/null 2>&1; then CC="c89";   fi
if [ "c89" = "${CC}" ] && ! which c89 >/dev/null 2>&1; then CC="cc";    fi
if [ "cc"  = "${CC}" ] && ! which cc  >/dev/null 2>&1; then CC="gcc";   fi
if [ "gcc" = "${CC}" ] && ! which gcc >/dev/null 2>&1; then CC="false"; fi

#
# Compile the utility.
#
"${CC}" -s -o "bin/strptime.new" "bin/strptime.c" || \
	{
		printf "%s\n" "Error compiling 'bin/strptime.c' to 'bin/strptime.new' using compiler '${CC}'." | fold -s >&2
		exit 1
	}

#
# Test that the compiled utility works.
#
TEST="$( "bin/strptime.new" "test" "test" "test" 2>/dev/null )" || \
	{ printf "%s\n" "Compiled 'bin/strptime.new' doesn't work." >&2; exit 1; }
if [ "test" != "${TEST}" ]
then
	printf "%s\n" "Compiled 'bin/strptime.new' appeared to work but doesn't work right." | fold -s >&2
	exit 1
fi

#
# The newly compiled utility works, so replace the old compiled utility if there is one.
#
rm -f -- "bin/strptime"
mv -f -- "bin/strptime.new" "bin/strptime"

#
# Retest the utility, just in case something zany happened during replacement.
#
TEST="$( "bin/strptime" "test" "test" "test" 2>/dev/null )" || \
	{
		printf "%s\n" "Compiled 'bin/strptime' doesn't work despite working as 'bin/strptime.new' a moment ago." | fold -s >&2
		exit 1
	}
if [ "test" != "${TEST}" ]
then
	printf "%s\n" "Compiled 'bin/strptime' worked right as 'bin/strptime.new' but doesn't work right anymore." | fold -s >&2
	exit 1
fi

# End.

