#!/bin/sh

# Terminal width: 132 columns.
# Function definitions end at comment "# Program proper start."

#
# Print usage and exit.
#
usage() {
	usageflag="$1"
	usageself="$( basename "$0" )"
	usagemessage="$( cat <<- HERE
	Wrap markdown.pl (or another LML translator) and catch its output.

	Usage:

	${usageself} -h|-?
	${usageself} command from_file f to_file t

	-h or -?     Show this help text and exit without error.
	command      LML-to-HTML translation command.
	from_file    File containing LML to translate.
	f            A literal lowercase F.
	to_file      File to save translated HTML fragment in.
	t            A literal lowercase T.

	Command line options must appear in the order shown.

	This is a wrapper for translation commands that dump their output to stdout
	and expect it to be piped where needed, without the ability to specify a
	destination file name directly.

	Specify file names with all necessary paths, either absolute or relative to
	the current directory, not relative to the directory in which
	${usageself} lives.
	HERE
	)"
	if [ -n "${usageflag}" ]
	then printf "%s\n" "${usagemessage}"; exit 0
	else printf "%s\n" "${usagemessage}" >&2; exit 1
	fi
}


#
# Print an error message, then print usage and exit.
#
errmsg() {
	if [ -z "$1" ]; then return; fi
	printf "%s\n" "$1" >&2
	usage
}


#
# Print an error message, then exit.
#
abortmsg() {
	if [ -z "$1" ]; then return; fi
	printf "%s\n" "$1" >&2
	exit 1
}
	

#
# Process command line options and initialize variables.
#
setoptions() {
	unset FROM_FILE TO_FILE XLAT

	if [     -z "$1" ]; then usage; fi
	if [ "-h" = "$1" ]; then usage help; fi
	if [ "-?" = "$1" ]; then usage help; fi
	if [     -n "$1" ]; then XLAT="$1"; fi
	if [     -n "$2" ]; then FROM_FILE="$2"; fi
	if [ "f" != "$3" ]; then usage; fi
	if [     -n "$4" ]; then TO_FILE="$4"; else usage; fi
	if [ "t" != "$5" ]; then usage; fi
}


#
# Program proper start.
#
# Process command line options.
#
setoptions "$@"

#
# Perform the LML-to-HTML translation.
#
which "${XLAT}" >/dev/null 2>&1 || { errmsg "Command '${XLAT}' not found."; }
if [ -f "${FROM_FILE}" ]
then "${XLAT}" "${FROM_FILE}" > "${TO_FILE}"
else errmsg "File '${FROM_FILE}' not found."
fi
if [ ! -s "${TO_FILE}" ]; then errmsg "File '${TO_FILE}' is empty."; fi


#
# All work done.
#
# End.

