#!/bin/sh

# Default date format: "Friday, January 1, 2021"
#
defdatefmt="%A, %B %e, %Y"

# If the site has a dateformat file, include it.
#
if [ -r "dateformat" ]
then
	junk="$( sed -n "1p" "dateformat" )"
	if [ "#!/bin/false" = "${junk}" ]
	then
		. "dateformat"
	fi
fi
if [ -n "${dateformat}" ]; then defdatefmt="${dateformat}"; fi

to36() {
	# Provided a base-10 expression of a base 36 digit, return a single digit
	# with the uppercase letters A-Z filling in positions 10-35.
	to36d=""
	case "$1" in
	00)  to36d="0"  ;;  06)  to36d="6"  ;;  12)  to36d="C"  ;;  18)  to36d="I"  ;;  24)  to36d="O"  ;;  30)  to36d="U"  ;;
	01)  to36d="1"  ;;  07)  to36d="7"  ;;  13)  to36d="D"  ;;  19)  to36d="J"  ;;  25)  to36d="P"  ;;  31)  to36d="V"  ;;
	02)  to36d="2"  ;;  08)  to36d="8"  ;;  14)  to36d="E"  ;;  20)  to36d="K"  ;;  26)  to36d="Q"  ;;  32)  to36d="W"  ;;
	03)  to36d="3"  ;;  09)  to36d="9"  ;;  15)  to36d="F"  ;;  21)  to36d="L"  ;;  27)  to36d="R"  ;;  33)  to36d="X"  ;;
	04)  to36d="4"  ;;  10)  to36d="A"  ;;  16)  to36d="G"  ;;  22)  to36d="M"  ;;  28)  to36d="S"  ;;  34)  to36d="Y"  ;;
	05)  to36d="5"  ;;  11)  to36d="B"  ;;  17)  to36d="H"  ;;  23)  to36d="N"  ;;  29)  to36d="T"  ;;  35)  to36d="Z"  ;;
	esac
	printf "%s" "${to36d}"
}

from10to36() {
	# Provided an arbitrary base 10 number, convert it to a base 36 number.
	#
	if [ -z "$1" ]; then return; fi
	printf "%s\n" "obase=36; $1" | bc | tr ' ' '\n' | while read -r digit; do to36 "${digit}"; done
}

#
# Program proper start.
#
datestr="$1"; datefmt="$2"
if [ -z "${datestr}" ]
then
	printf "%s\n%s\n" "Error: no date string was given." "Usage: rickdate.sh \"date_string\" [ \"date_format_string\" ]" >&2
	exit 1
fi

if [ -z "${datefmt}" ]; then datefmt="${defdatefmt}"; fi

teststr="$( bin/strptime "test" "test" "test" )"
if [ "test" != "${teststr}" ]
then
	make strptime >&2 || { printf "%s\n" "Error: can't translate date string to rickdate." >&2; exit 1; }
	teststr="$( bin/strptime "test" "test" "test" )"
	if [ "test" != "${teststr}" ]; then printf "%s\n" "Error: can't translate date string to rickdate." >&2; exit 1; fi
fi

deciyear="$( bin/strptime "${datestr}" "${datefmt}" "%Y" )"
decimont="$( bin/strptime "${datestr}" "${datefmt}" "%m" )"
decidate="$( bin/strptime "${datestr}" "${datefmt}" "%d" )"

rickyear="$( from10to36 "${deciyear}" )"; rickmont="$( from10to36 "${decimont}" )"; rickdate="$( from10to36 "${decidate}" )"

rickdate="${rickyear}${rickmont}${rickdate}"

if [ -z "${rickdate}" ]
then printf "%s\n" "Error: unable to turn date string '${datestr}' into a rickdate." >&2; exit 1
else printf "%s\n" "${rickdate}"
fi

# End.

